@media print {
 *,
 *:before,
 *:after,
 *:first-letter,
 p:first-line,
 div:first-line,
 blockquote:first-line,
 li:first-line {
    background: transparent !important;
    color: #000 !important;
    box-shadow: none !important;
    text-shadow: none !important;
 }

 header, footer,
 nav .sidenav-trigger,
 #nav-mobile,
 .right-panel,
 .breadcrumbs,
 .fixed-action-btn,
 .card-action {
   display: none;
 }

 .topbar {
   padding-left: 25px;
 }

 .left-panel {
  flex-basis: 100%;
 }

}
