{% load i18n material_form material_form_internal %}
{% get_current_language as LANGUAGE_CODE %}
{% get_language_info for LANGUAGE_CODE as lang %}
<div class="row">
    <div{% attrs bound_field 'group' %}
        id="id_{{ bound_field.html_name }}_container"
        class="input-field col s12{% if field.required %} required{% endif %}{% if bound_field.errors %} has-error{% endif %}"
    {% endattrs %}>
        {% part field prefix %}{% endpart %}{% part field control %}
        <input{% attrs bound_field 'widget' default field.widget.attrs %}
            id="id_{{ bound_field.html_name }}"
            name="{{ bound_field.html_name }}"
            type="{{ field.widget.input_type }}"
            autocomplete="false"
            data-date-format="{{ field|jquery_datepicker_format }}"
            data-form-control="time"
            data-lang="{{ lang.code|default:'en' }}"
            {% if field.disabled %}disabled{% endif %}
            {% if bound_field.errors %}class="invalid"{% endif %}
            {% if bound_field.value %}value="{{ bound_field.value|datepicker_value:field.input_formats.0 }}"{% endif %}
        {% endattrs %}>
        {% endpart %}
        {% part field label %}
        <label{% attrs bound_field 'label' %}
            for="{{ bound_field.id_for_label }}"
            {% if bound_field.value %}class="active"{% endif %}
        {% endattrs %}>{{ bound_field.label }}</label>
        {% endpart %}
        {% part field help_text %}{% if field.help_text %}
        <div class="help-block">{{ bound_field.help_text|safe }}</div>
        {% endif %}
        {% endpart %}{% part field errors %}
        {% if bound_field.errors %}
            {% include  'material/field_errors.html' %}
        {% endif %}{% endpart %}{{ hidden_initial }}
    </div>
</div>
